AsyncDigestVerifier

Trait AsyncDigestVerifier 

pub trait AsyncDigestVerifier<D: Update, S> {
    // Required method
    async fn verify_digest_async<F: AsyncFn(&mut D) -> Result<(), Error>>(
        &self,
        f: F,
        signature: &S,
    ) -> Result<(), Error>;
}
Asynchronously verify the provided signature for the given prehashed message Digest is authentic.

Required Methods

async fn verify_digest_async<F: AsyncFn(&mut D) -> Result<(), Error>>( &self, f: F, signature: &S, ) -> Result<(), Error>

Asynchronously verify the signature against the received Digest output, by updating it with the message.

The given function can be invoked multiple times. It is expected that in each invocation the Digest is updated with the entire equal message.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors